clear;clc;

% Load GDP and debt data

load data_BOE YBHA3 debt_boe % GDP is 1700-2017, Debt is 1691-2016

% Load Quantity data (Q3 and Q4 contain different gilts)

Q1 = dataset('XLSFile','Q_1694m3-1860m2.xlsx');
Q2 = dataset('XLSFile','Q_1860m3-1881m2.xlsx');
Q3 = dataset('XLSFile','Q_1881m1-1947m12.xlsx');
Q4 = dataset('XLSFile','Q_1900m11-1947m12.xlsx');
Q5 = dataset('XLSFile','Q_1946m1-2018m12.xlsx');
Q=[Q1;Q2(Q2.Year<1881,:);Q3;Q4;Q5(Q5.Year>1947,:)];

% Define period of interest

startyear=1700;
endyear=2017;

% Define variables to store results

debt=zeros((endyear-startyear+1),1);
index_for_debt=zeros((endyear-startyear+1),2);

% Loop through years

for year=startyear:endyear
    
    year
    
    % Store year

    index_for_debt((year-startyear)+1,1)=year;
    
    % Select gilts for which quantity>0 in December of year

    Qtemp=Q(Q.Year==year & Q.Month==12 & Q.Q>0,:);
    
    % Calculate face value of all outstanding gilts
    
    debt((year-startyear)+1)=sum(100*Qtemp.Q);

end

%Figure 1: Face value of total and marketable debt as a percentage of GDP

figure(1);
subplot(2,1,1);
plot(index_for_debt(1:end,1),[100*debt_boe(1+9:end,1)./YBHA3(1:end),debt(1:end,1)./YBHA3(1:end)],'LineWidth',2);
title('Face value of total and marketable debt as a percentage of GDP');
legend('Total debt','Marketable debt','Location','northwest');
set(gca,'FontSize',24);
ylabel('Debt-to-GDP ratio','FontSize',24);
xlim([1680 2020]);