clear;clc;

% Load face and market values of debt at monthly frequency

load debt_data debt_face debt_face_n debt_face_i debt_market ...
     debt_market_n debt_market_i startyear endyear;
 
% Load nominal payments at monthly frequency

load returns_data index_for_pay pay pay1 pay2;
startyearPAY=1692; endyearPAY=2017; % For payments data

% Load GDP and debt data

load data_BOE YBHA3 YBHA3_real debt_boe % GDP is 1700-2017, Debt is 1691-2016
startyearGDP=1700; endyearGDP=2017;

% Define period of interest

startyear=1730;
endyear=2017;

% Define variable to store results

coupons=zeros(endyear-startyear+1,1);
capgains=zeros(endyear-startyear+1,1);
capgainsMA=zeros(endyear-startyear+1,1);
years=zeros(endyear-startyear+1,1);

% Loop through years to extract coupon payaments and capital gains

for i=startyear:endyear
    
    % Annual coupon payments and capital gains
    
	coupons(i-startyear+1)=pay1((i-(startyearPAY+1)+1)*12+1)/YBHA3(i-startyearGDP+1);
    capgains(i-startyear+1)=pay2((i-(startyearPAY+1)+1)*12+1)/YBHA3(i-startyearGDP+1);
       
    % Adjust capital gains for indexation of indexed bonds
    
    d1_i=debt_market_i((i-startyearPAY-1)*12+12)/YBHA3(i-startyearGDP);
    GDP_deflator1=YBHA3(i-startyearGDP)/YBHA3_real(i-startyearGDP);
    GDP_deflator2=YBHA3(i-startyearGDP+1)/YBHA3_real(i-startyearGDP+1);
    capgains(i-startyear+1)=capgains(i-startyear+1)-((GDP_deflator2-GDP_deflator1)/GDP_deflator1)*d1_i;
    
    % Take MA of capgains
    
    if i-startyear+1>4
        capgainsMA(i-startyear+1)=mean(capgains(i-startyear+1-4:i-startyear+1));
    end
    
    % Populate years
    
    years(i-startyear+1)=i;

end

% Figure 6: Coupon payments and revaluations of marketable debt

figure(6);
subplot(2,1,1);
plot(years(5:end),[coupons(5:end) coupons(5:end)+capgainsMA(5:end)],'LineWidth',2);
set(gca,'FontSize',16)
ylabel('Coupons and revaluations');
legend('Coupons/GDP','(Coupons+Revaluations)/GDP','Location','NorthEast');
hold on;
plot(years,0*coupons./coupons,'color','k','LineWidth',0.5,'HandleVisibility','off');
xlim([1730 2020]);



